#!/usr/bin/perl -w -I/usr/sausalito/perl -I.
# $Id: 10_addSystem.pl,v 1.5.2.2 2002/03/12 00:44:45 pbaltz Exp $
# Copyright 2000-2002 Sun Microsystems, Inc.  All rights reserved.

use strict;
use CCE;
use I18n;

my $errors = 0;

my %locales = (  
	"en_US" => "&en&",
	"ja" => "&ja&"
);

my $cce = new CCE;
$cce->connectuds();

my ($fullbuild) = `cat /etc/build`;
chomp($fullbuild);

# figure out our product
my ($product, $build, $lang) = ($fullbuild =~ m/^build (\S+) for a (\S+) in (\S+)/);

#
# figure out which locales the machine has available.  Just look for this
# module, because it will have all the supported locales.
#
my $available_langs = $cce->array_to_scalar(I18n::getAvailableLocales('base-system'));

# count the systems;
my @oids = $cce->find("System");
if ($#oids == 0) {
	# we have one and only one System object.  hooray.
} elsif ($#oids < 0) {
	# we must create a System object with no properties.
	$cce->create("System", {
		productBuildString=>$fullbuild,
		productIdentity => $product,
		productBuild => $build,
		productLanguage => $lang,
		console=>"0",
		locales => $available_langs
	});
	$oids[0] = $cce->oid();
} else { # we have more than one System object.
	print STDERR "ERROR: Multiple system objects detected!\n";
	print STDERR "       attempting to repair...\n";
	shift(@oids); # don't delete this one.
	foreach $_ (@oids) {
		my ($success) = $cce->destroy($_);
		if ($success) {
			print STDERR "       Deleted System object $_\n";
		} else {
			print STDERR "       FAILED to delete System object $_\n";
			$errors++;
		}
	}
}

# sync console (redundant on first create, safe on all others)
# we do it this way, because the console flag may change at powerup
my $conval = `/sbin/nvram -c console`;
chomp($conval);
$cce->set($oids[0], "", { console => $conval eq "on" ? "1" : "0"}) if $oids[0];

# update System.locales everytime in case we add/remove a locale
if ($oids[0]) {
	$cce->set($oids[0], '', { 'locales' => $available_langs });
}

$cce->bye();
exit($errors);
	

